@@ -134,36 +134,41 @@ class BaseLog:
 
     def debug(self, msg, *args, **kwargs):
         try:
+            msg = msg % args
             message = self.program_model('DEBUG', msg, kwargs.get('extra'))
-            logging.getLogger(self.program_log_name).debug(message, *args, **kwargs)
+            logging.getLogger(self.program_log_name).debug(message)
         except Exception as e:
             print(e)
 
     def info(self, msg, *args, **kwargs):
         try:
+            msg = msg % args
             message = self.program_model('INFO', msg, kwargs.get('extra'))
-            logging.getLogger(self.program_log_name).debug(message, *args, **kwargs)
+            logging.getLogger(self.program_log_name).debug(message)
         except Exception as e:
             print(e)
 
     def warn(self, msg, *args, **kwargs):
         try:
+            msg = msg % args
             message = self.program_model('WARN',  msg, kwargs.get('extra'))
-            logging.getLogger(self.program_log_name).warn(message, *args, **kwargs)
+            logging.getLogger(self.program_log_name).warn(message)
         except Exception as e:
             print(e)
 
     def error(self, msg, *args, **kwargs):
         try:
+            msg = msg % args
             message = self.program_model('ERROR', msg, kwargs.get('extra'))
-            logging.getLogger(self.program_log_name).error(message, *args, **kwargs)
+            logging.getLogger(self.program_log_name).error(message)
         except Exception as e:
             print(e)
 
     def exception(self, msg, *args, **kwargs):
         try:
+            msg = msg % args
             message = self.program_model('ERROR', msg, kwargs.get('extra'))
-            logging.getLogger(self.program_log_name).error(message, *args, **kwargs)
+            logging.getLogger(self.program_log_name).error(message)
         except Exception as e:
             print(e)
 
